defineITN: Writes the ITN intervention parameterisation xml chunk

View source: R/xml_interventions_define.R

defineITNR Documentation

Writes the ITN intervention parameterisation xml chunk

Description

Writes the ITN intervention parameterisation xml chunk

Usage

defineITN(
  baseList,
  component = "histITN",
  noeffect = "outdoor",
  mosquitos,
  halflife = 2,
  resist = TRUE,
  historical = FALSE,
  strong = FALSE
)

define_ITN(
  baseList,
  component = "histITN",
  noeffect = "outdoor",
  mosquitos,
  halflife = 2,
  resist = TRUE,
  historical = FALSE,
  strong = FALSE
)

Arguments

baseList

List with experiment data.

component

Name of the intervention, can be any name but needs to be the same as defined in deployment.

noeffect

Which mosquitoes unaffected by intervention?

mosquitos

Name of mosquito species affected by the intervention

halflife

Attrition of nets in years

resist

If TRUE, a pyrethroid resistance will be assumed (default percentage..?)

historical

Used for historical intervention coverage?

strong

If !strong and !resist, then "Pitoa" parameter for LLIN


SwissTPH/r-openMalariaUtilities documentation built on Sept. 14, 2024, 1:34 a.m.