View source: R/xml_interventions_define.R
| defineLarv | R Documentation |
Function that writes the larviciding component
defineLarv(
baseList,
mosquitos,
component = "LSM",
coverage = "@futLSMcov@",
decayVals = list(L = 0.25, k = NULL, funct = "step"),
startDate = NULL,
endDate = NULL,
interval = NULL,
dates = NULL
)
define_larv(
baseList,
mosquitos,
component = "LSM",
coverage = "@futLSMcov@",
decayVals = list(L = 0.25, k = NULL, funct = "step"),
startDate = NULL,
endDate = NULL,
interval = NULL,
dates = NULL
)
baseList |
List with experiment data. |
mosquitos |
Names of mosquito species to simulate. |
component |
Name of vector population intervention (i.e. LSM). |
coverage |
A variable or a numeric value. Can be a placeholder. |
decayVals |
Decay (if not specified, constant effectiveness, step function as default) |
startDate |
Date in YYYY-MM-DD format. |
endDate |
Date in YYYY-MM-DD format. |
interval |
A string like '1 weeks'. Same as in |
dates |
If NULL, startDate, endDate and interval are used, else a vector of dates in YYYY-MM-DD format. Can be a placeholder. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.