View source: R/xml_interventions_define.R
| define_larv_compat | R Documentation |
Function that writes the larviciding component xml chunk
define_larv_compat(
baseList,
mosqs,
component = "LSM",
coverage = "@futLSMcov@",
decayVals = list(L = 0.25, k = NULL, funct = "step"),
y1 = 2018,
y2 = 2030,
m1 = 4,
m2 = 6,
every = 2,
interval = "week",
SIMSTART = "1918-01-01"
)
baseList |
List with experiment data. |
mosqs |
Names of mosquito species to simulate |
component |
Name of vector population intervention (i.e. LSM) |
coverage |
A variable or a numeric value |
decayVals |
Decay (if not specified, constant effectiveness, step function as default) |
y1 |
Year of the first date (surveys starting from year y1) |
y2 |
Year of the end date (surveys continuing until year y2) |
m1 |
Month of the first date |
m2 |
Month of the end date |
every |
Integer value |
interval |
Month, year, week, quarter |
SIMSTART |
Starting date of the simulations in the format "yyyy-mm-dd", default e.g. "1918-01-01" |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.